@@ -385,7 +385,7 @@ main(int argc,
 					GTK_STOCK_QUIT, GTK_RESPONSE_CLOSE, NULL);
 		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
 		gtk_window_set_title (GTK_WINDOW (dialog), _("Invalid mixer device"));
-		show_error (dialog);
+		show_error GTK_DIALOG(dialog);
 	}
 
 	return 0;
@@ -1745,10 +1745,10 @@ about_cb (GtkWidget *widget,
 		gdk_window_show (about->window);
 		gdk_window_raise (about->window);
 	} else {
-		about = gnome_about_new ( _("Gnome Volume Control"), VERSION,
-					  "(C) 1998 Jens Ch. Restemeier\n"
-					  "(C) 2001-2002 Iain Holmes",
-					  _("This is a mixer for sound devices"),
+		about = gnome_about_new ( _("Volume Control"), VERSION,
+					  "Copyright (C) 1998 Jens Ch. Restemeier\n"
+					  "Copyright (C) 2001, 2002 Iain Holmes",
+					  _("A mixer for sound devices"),
 					  authors,
 					  NULL, NULL,
 					  NULL);
